aboutsummaryrefslogtreecommitdiffstats
path: root/admin/thumbnail.php
diff options
context:
space:
mode:
Diffstat (limited to 'admin/thumbnail.php')
-rw-r--r--admin/thumbnail.php8
1 files changed, 4 insertions, 4 deletions
diff --git a/admin/thumbnail.php b/admin/thumbnail.php
index d2269762f..cdd864af2 100644
--- a/admin/thumbnail.php
+++ b/admin/thumbnail.php
@@ -68,12 +68,12 @@ function get_images_without_thumbnail( $dir )
return $images;
}
// scandir scans a dir to find pictures without thumbnails. Once found,
// creation of the thumbnails (RatioResizeImg). Only the first $_POST['n']
// pictures without thumbnails are treated.
// scandir returns an array with the generation time of each thumbnail (for
// statistics purpose)
-function scandir( $dir, $width, $height )
+function pwg_scandir( $dir, $width, $height )
{
global $conf;
$stats = array();
@@ -297,7 +297,7 @@ if ( isset( $_GET['dir'] ) )
if ( count( $errors ) == 0 )
{
$vtp->addSession( $sub, 'results' );
- $stats = scandir( $_GET['dir'], $_POST['width'], $_POST['height'] );
+ $stats = pwg_scandir( $_GET['dir'], $_POST['width'], $_POST['height'] );
$times = array();
foreach ( $stats as $stat ) {
array_push( $times, $stat['time'] );
@@ -68,12 +68,12 @@ function get_images_without_thumbnail( $dir )
return $images;
}
-// scandir scans a dir to find pictures without thumbnails. Once found,
+// pwg_scandir scans a dir to find pictures without thumbnails. Once found,
// creation of the thumbnails (RatioResizeImg). Only the first $_POST['n']
// pictures without thumbnails are treated.
@@ -68,12 +68,12 @@ function get_images_without_thumbnail( $dir )
// creation of the thumbnails (RatioResizeImg). Only the first $_POST['n']
// pictures without thumbnails are treated.
-// scandir returns an array with the generation time of each thumbnail (for
+// pwg_scandir returns an array with the generation time of each thumbnail (for
// statistics purpose)